@@ -5,10 +5,15 @@ from ..caller.config_manager_caller import ConfigManagerCaller
 
 
 class ConfigManager(Module):
-    def __init__(self, app_id, set):
+    def __init__(self, app_id, set, init):
         super().__init__(app_id, 'config', set)
         self.app_id = app_id
         self.caller = ConfigManagerCaller(self.app_id)
+        if init:
+            self.init()
+
+    def init(self):
+        self.caller.init_bot_config()
 
     def get_backfill_answers(self) -> list:
         """
