@@ -127,9 +127,13 @@ class KnowledgeGraph(Module):
     知识图谱
     """
 
-    def __init__(self, app_id,set):
-        super().__init__(app_id, 'kg',set)
+    def __init__(self, app_id, set, init):
+        super().__init__(app_id, 'kg', set)
         self.caller = KnowledgeGraphCaller(app_id)
+        if init:
+            self.init()
+
+    def init(self):
         self.caller.init_data()
 
     # 下面是 second version 增量训练
