@@ -11,6 +11,10 @@ class Answer:
         if self.related:
             return 'text: {},related: {}, score: {}'.format(self.text,self.related, self.score if self.score else 0.0)
         return 'text: {}, score: {}'.format(self.text,self.score if self.score else 0.0)
-
     def __repr__(self):
         return self.__str__()
+
+    def keys(self):
+        return ('text', 'related', 'score')
+    def __getitem__(self, item):
+        return getattr(self, item)
